@@ -81,8 +81,8 @@ class RegexPatternPhp(object):
         (re.compile(r',\s*std::\$*placeholders::\$*_\d'), r'', ['std::$placeholders']),
         (re.compile(r'list_remove\((\$.+?),\s*([\$.\w]+?)\);'), r'array_splice(\1, array_search(\2, \1), 1);',
          ['list_remove']),
-        (re.compile(r'list_erase\((\$.+?),\s*([\$.\w]+?)\);'), r'array_splice(\1, \2, 1);',
-         ['list_erase']),
+        (re.compile(r'list_erase\((\$.+?),\s*([\$.\w]+?)\);'), r'array_splice(\1, \2, 1);', ['list_erase']),
+        (re.compile(r'list_truncate\s*\(\s*(.+),\s*(.+)\s*\)'), r'\1 = array_splice(\1, 0, \2)', ['list_truncate']),
         (re.compile(r'list_clear\((.+?)\);'), r'\1 = array();', ['list_clear']),
         (re.compile(r'list_resize\s*\(\s*(.+),\s*(.+)\s*\)'), r'\1 = array_fill(0, \2, NULL);', ['list_resize']),
         (re.compile(r'string_empty\((.+?)\)'), r'empty(\1)', ['string_empty']),
