@@ -1,4 +1,5 @@
 from .constants import FACTORY
+from .writer import Writer
 
 
 class GeneratorFactory(object):
@@ -8,12 +9,15 @@ class GeneratorFactory(object):
 
     @staticmethod
     def generate(model):
+        writer = Writer('')
+        writer.model = model
         line = '''
         if type == "{0}":
-            from . import {0}
-            return {0}.{0}()'''
+            from .{0} import {0}
+            return {0}()'''
         builders = ''
         for cls in model.classes:
             builders += line.format(cls.name)
         content = FACTORY.format(builders=builders)
-        model.add_file('Factory.py', content)
+        content = writer.prepare_file(content)
+        model.add_file(None, 'Factory.py', content)
